@@ -39,6 +39,10 @@ def execute_stream(client: SSHClient, command: str, *, is_silent=True):
                 sys.stderr.write(channel.recv_stderr(1024).decode('utf-8'))
             if channel.exit_status_ready():
                 break
+        while channel.recv_ready():
+            sys.stdout.write(channel.recv(1024).decode('utf-8'))
+        while channel.recv_stderr_ready():
+            sys.stderr.write(channel.recv_stderr(1024).decode('utf-8'))
         exit_code = channel.recv_exit_status()
 
         if exit_code != 0:
@@ -116,17 +120,15 @@ def rsync_project():
 
     exclude_path = Path('.') / '.remote' / 'exclude.txt'
     exclude_path = exclude_path.absolute()
-    rsync_cmd = ['rsync', '-ravuKLt', '--perms', '--executability']
-    if conf.password is not None or conf.private_key_file is None:
-        raise NotImplementedError('TODO: Not implemented to handle connections with password')
-    rsync_cmd += ['-e']
-    rsync_cmd += [f'"ssh -o StrictHostKeyChecking=no -i {conf.private_key_file}"']
+    rsync_cmd = ['rsync', '-zravuKLt', '--perms', '--executability']
+    if conf.private_key_file is not None:
+        rsync_cmd += ['-e']
+        rsync_cmd += [f'"ssh -o StrictHostKeyChecking=no -i {conf.private_key_file}"']
     if exclude_path.exists():
         rsync_cmd += [f"--exclude-from='{str(exclude_path)}'"]
     rsync_cmd += ['./']  # source
     rsync_cmd += [f'{conf.username}@{conf.hostname}:~/{conf.name}/']  # destination
 
-    # print(' '.join(rsync_cmd))
     try:
         process = subprocess.run(' '.join(rsync_cmd), shell=True)
     except FileNotFoundError as e:
@@ -162,8 +164,7 @@ def run_command(client: SSHClient, home_path: str, command: List[str]):
     script = template(conf.scripts_folder / 'run.sh', {
         'name': conf.name,
         'home': home_path,
-        'has_pipfile': str(pipfile.exists()),
-        'has_requirements': str(requirements.exists()),
+        'use_pipenv': str(pipfile.exists()),
         'run_command': ' '.join(command)
     })
 
