@@ -3,8 +3,7 @@
 # Configurations
 readonly NAME="%%NAME%%"
 readonly HOME='%%HOME%%'
-readonly HAS_PIPFILE='%%HAS_PIPFILE%%'
-readonly HAS_REQUIREMENTS='%%HAS_REQUIREMENTS%%'
+readonly USE_PIPENV='%%USE_PIPENV%%'
 readonly RUN_COMMAND='%%RUN_COMMAND%%'
 
 readonly PROJECT_PATH="${HOME}/${NAME}"
@@ -14,7 +13,7 @@ readonly CONDA_ENV="${NAME}_env"
 # Text colors
 # 31 red 32 green 33 yellow 34 blue
 
-update() {
+run_python() {
   source "${CONDA_PATH}/etc/profile.d/conda.sh"
   if [ "$?" != 0 ]; then
     return 1
@@ -31,7 +30,7 @@ update() {
   fi
 
   local run_command="${RUN_COMMAND}"
-  if [ "${HAS_PIPFILE}" == "True" ]; then
+  if [ "${USE_PIPENV}" == "True" ]; then
     run_command="pipenv run ${RUN_COMMAND}"
   fi
 
@@ -43,4 +42,4 @@ update() {
   return 0
 }
 
-update
+run_python
